@@ -218,6 +218,7 @@ module Fog
 
     def self.regions
       @regions ||= [
+        'ap-east-1',
         'ap-northeast-1', 'ap-northeast-2', 'ap-northeast-3',
         'ap-south-1',
         'ap-southeast-1', 'ap-southeast-2',
@@ -225,6 +226,7 @@ module Fog
         'cn-north-1',
         'cn-northwest-1',
         'eu-central-1',
+        'eu-north-1',
         'eu-west-1', 'eu-west-2', 'eu-west-3',
         'us-east-1', 'us-east-2',
         'us-west-1', 'us-west-2',
