@@ -101,6 +101,7 @@ module Fog
       request :describe_classic_link_instances
       request :describe_dhcp_options
       request :describe_images
+      request :describe_image_attribute
       request :describe_instances
       request :describe_instance_attribute
       request :describe_internet_gateways
@@ -143,6 +144,7 @@ module Fog
       request :import_key_pair
       request :modify_image_attribute
       request :modify_instance_attribute
+      request :modify_instance_placement
       request :modify_network_interface_attribute
       request :modify_snapshot_attribute
       request :modify_subnet_attribute
@@ -452,7 +454,7 @@ module Fog
 
         def tagged_resources(resources)
           Array(resources).map do |resource_id|
-            if match = resource_id.match(/^(\w+)-[a-z0-9]{8}/i)
+            if match = resource_id.match(/^(\w+)-[a-z0-9]{8,17}/i)
               id = match.captures.first
             else
               raise(Fog::Service::NotFound.new("Unknown resource id #{resource_id}"))
