@@ -1,6 +1,6 @@
 module Fog
-  module Storage
-    class AWS
+  module AWS
+    class Storage
       class Real
         require 'fog/aws/parsers/storage/get_bucket_lifecycle'
 
@@ -25,7 +25,7 @@ module Fog
                     :bucket_name => bucket_name,
                     :idempotent => true,
                     :method   => 'GET',
-                    :parser   => Fog::Parsers::Storage::AWS::GetBucketLifecycle.new,
+                    :parser   => Fog::Parsers::AWS::Storage::GetBucketLifecycle.new,
                     :query    => {'lifecycle' => nil}
                   })
         end
